.. AUTO-GENERATED FILE -- DO NOT EDIT!

core.poll
=========

Module: :mod:`core.poll`
------------------------
Inheritance diagram for ``zmq.core.poll``:

.. inheritance-diagram:: zmq.core.poll 
   :parts: 3

.. automodule:: zmq.core.poll

.. currentmodule:: zmq.core.poll

:class:`Poller`
---------------


.. autoclass:: Poller
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:


.. autofunction:: zmq.core.poll.select

